searchData={"items":[{"type":"protocol","title":"Warder.Element","doc":"Protocol for Element Implementations.\n\nAny data type that can be used as an element in a range must implement this\nprotocol.","ref":"Warder.Element.html"},{"type":"protocol","title":"Discrete Ranges - Warder.Element","doc":"Discrete ranges are ranges where the elements are not continuous. For example,\na range of integers from 1 to 10 is a discrete range. There is no elements\nbetween 1 and 2, 2 and 3, and so on. The elements are separated by a step of\n1.\n\nIn discrete ranges, the `consecutive?/2` function must return `true` if the\ntwo elements are consecutive. For example, in a range of integers, 1 and 2 are\nconsecutive, but 1 and 3 are not.\n\nThe `canonicalize/1` function must return the next element in the range. For\nexample, if the range is from 1 to 10, and the element is 1, the\n`canonicalize/1` function must return 2.\n\nIndiscrete ranges are ranges where the elements are continuous. For example, a\nrange of floats from 1.0 to 10.0 is an indiscrete range. There are infinite\nelements between 1.0 and 2.0, 2.0 and 3.0, and so on.\n\nIn indiscrete ranges, the `consecutive?/2` function must return `false` for\nany two elements. The `canonicalize/1` function must return `:error`.","ref":"Warder.Element.html#module-discrete-ranges"},{"type":"protocol","title":"Example - Warder.Element","doc":"defimpl Warder.Element, for: Date do\n      def compare(left, right), do: Date.compare(left, right)\n\n      def consecutive?(left, right), do: Date.diff(left, right) == 1\n\n      def canonicalize(value), do: {:ok, Date.add(value, 1)}\n    end","ref":"Warder.Element.html#module-example"},{"type":"protocol","title":"Implementations - Warder.Element","doc":"The protocol is defined for the following types:\n\n* `Float`\n* `Integer`\n* `DateTime`\n* `NaiveDateTime`\n* `Time`\n* `Decimal`","ref":"Warder.Element.html#module-implementations"},{"type":"function","title":"Warder.Element.canonicalize/1","doc":"Canonicalize value a step up.\n\nAlways returns `:error` for indiscrete ranges.","ref":"Warder.Element.html#canonicalize/1"},{"type":"function","title":"Warder.Element.compare/2","doc":"Compare two elements.\n\nReturns `:lt` if the left element is less than the right element, `:eq` if\nthey are equal, and `:gt` if the left element is greater than the right\nelement.","ref":"Warder.Element.html#compare/2"},{"type":"function","title":"Warder.Element.consecutive?/2","doc":"Are those two elements consecutive?\n\nThat means that no other elements can be between left and right.\n\nAlways returns `false` for indiscrete ranges.","ref":"Warder.Element.html#consecutive?/2"},{"type":"type","title":"Warder.Element.t/0","doc":"","ref":"Warder.Element.html#t:t/0"},{"type":"module","title":"Warder.Multirange","doc":"Multirange Implementation\n\n> ##","ref":"Warder.Multirange.html"},{"type":"module","title":"Creation / Manipulation {: .warning} - Warder.Multirange","doc":">\n> Multiranges should not be created or modified manually. Use `new/1`, or\n> `empty/0` to create multiranges.","ref":"Warder.Multirange.html#module-creation-manipulation-warning"},{"type":"module","title":"Ecto Type - Warder.Multirange","doc":"If `ecto` and `postgrex` are installed, you can use the `Warder.Multirange`\ntype:\n\n```elixir\ndefmodule Model do\n  use Ecto.Schema\n\n  alias Warder.Multirange\n\n  @type t :: %{multirange: Multirange.t(integer())}\n\n  schema \"models\" do\n    field :multirange, Multirange,\n      db_type: :int8multirange,\n      inner_type: :integer\n  end\nend\n```\n\n#","ref":"Warder.Multirange.html#module-ecto-type"},{"type":"module","title":"Options - Warder.Multirange","doc":"* `db_type` - The database type to use for the range column. For example\n  `:int8multirange`.\n* `inner_type` - The ecto type of the elements in the range. For example\n  `:integer`.","ref":"Warder.Multirange.html#module-options"},{"type":"function","title":"Warder.Multirange.adjacent?/2","doc":"Is first adjacent to second?\n\nBoth `first` and `second` can either be a multirange or a range.","ref":"Warder.Multirange.html#adjacent?/2"},{"type":"function","title":"Examples - Warder.Multirange.adjacent?/2","doc":"iex> Warder.Multirange.adjacent?(\n    ...>   Warder.Multirange.new([Warder.Range.new!(1, 10)]),\n    ...>   Warder.Multirange.new([Warder.Range.new!(20, 30)]\n    ...> ))\n    false\n\n    iex> Warder.Multirange.adjacent?(\n    ...>   Warder.Multirange.new([Warder.Range.new!(1, 10)]), Warder.Range.new!(20, 30)\n    ...> )\n    false\n\n    iex> Warder.Multirange.adjacent?(\n    ...>   Warder.Multirange.new([Warder.Range.new!(1, 10)]), Warder.Range.new!(10, 20)\n    ...> )\n    true","ref":"Warder.Multirange.html#adjacent?/2-examples"},{"type":"function","title":"Warder.Multirange.contains?/2","doc":"Check if `first` contains `second`.\n\nBoth `first` and `second` can either be a multirange, range or an element.\n\nDoes the first multirange contain the second multirange or range?","ref":"Warder.Multirange.html#contains?/2"},{"type":"function","title":"Examples - Warder.Multirange.contains?/2","doc":"iex> Warder.Multirange.contains?(\n    ...>   Warder.Multirange.new([Warder.Range.new!(1, 10)]),\n    ...>   Warder.Multirange.new([Warder.Range.new!(1, 5)])\n    ...> )\n    true\n\n    iex> Warder.Multirange.contains?(\n    ...>   Warder.Multirange.new([Warder.Range.new!(1, 10)]),\n    ...>   Warder.Range.new!(1, 10)\n    ...> )\n    true\n\n    iex> Warder.Multirange.contains?(\n    ...>   Warder.Multirange.new([Warder.Range.new!(1, 10)]),\n    ...>   5\n    ...> )\n    true\n\n    iex> Warder.Multirange.contains?(\n    ...>   Warder.Multirange.new([Warder.Range.new!(1, 10)]),\n    ...>   20\n    ...> )\n    false","ref":"Warder.Multirange.html#contains?/2-examples"},{"type":"function","title":"Warder.Multirange.difference/2","doc":"Computes the difference of the multiranges.","ref":"Warder.Multirange.html#difference/2"},{"type":"function","title":"Examples - Warder.Multirange.difference/2","doc":"iex> Warder.Multirange.difference(\n    ...>   Warder.Multirange.new([Warder.Range.new!(5, 20)]),\n    ...>   Warder.Multirange.new([Warder.Range.new!(10, 15)])\n    ...> )\n    %Warder.Multirange{ranges: [\n      %Warder.Range{lower: 5, upper: 10, lower_inclusive: true, upper_inclusive: false},\n      %Warder.Range{lower: 15, upper: 20, lower_inclusive: true, upper_inclusive: false}\n    ]}","ref":"Warder.Multirange.html#difference/2-examples"},{"type":"function","title":"Warder.Multirange.empty/0","doc":"Create new empty multirange","ref":"Warder.Multirange.html#empty/0"},{"type":"function","title":"Examples - Warder.Multirange.empty/0","doc":"iex> Warder.Multirange.empty()\n    %Warder.Multirange{ranges: []}","ref":"Warder.Multirange.html#empty/0-examples"},{"type":"function","title":"Warder.Multirange.intersection/2","doc":"Computes the intersection of the multiranges.","ref":"Warder.Multirange.html#intersection/2"},{"type":"function","title":"Examples - Warder.Multirange.intersection/2","doc":"iex> Warder.Multirange.intersection(\n    ...>   Warder.Multirange.new([Warder.Range.new!(5, 15)]),\n    ...>   Warder.Multirange.new([Warder.Range.new!(10, 20)])\n    ...> )\n    %Warder.Multirange{ranges: [\n      %Warder.Range{lower: 10, upper: 15, lower_inclusive: true, upper_inclusive: false}\n    ]}","ref":"Warder.Multirange.html#intersection/2-examples"},{"type":"function","title":"Warder.Multirange.left?/2","doc":"Is first strictly left of second?\n\nBoth `first` and `second` can either be a multirange or a range.","ref":"Warder.Multirange.html#left?/2"},{"type":"function","title":"Examples - Warder.Multirange.left?/2","doc":"iex> Warder.Multirange.left?(\n    ...>   Warder.Multirange.new([Warder.Range.new!(1, 10)]),\n    ...>   Warder.Multirange.new([Warder.Range.new!(20, 30)])\n    ...> )\n    true\n\n    iex> Warder.Multirange.left?(\n    ...>   Warder.Multirange.new([Warder.Range.new!(1, 10)]),\n    ...>   Warder.Range.new!(20, 30)\n    ...> )\n    true\n\n    iex> Warder.Multirange.left?(\n    ...>   Warder.Multirange.new([Warder.Range.new!(1, 10)]),\n    ...>   Warder.Range.new!(5, 15)\n    ...> )\n    false","ref":"Warder.Multirange.html#left?/2-examples"},{"type":"function","title":"Warder.Multirange.merge/1","doc":"Computes the smallest range that all parts of the multirange.","ref":"Warder.Multirange.html#merge/1"},{"type":"function","title":"Examples - Warder.Multirange.merge/1","doc":"iex> Warder.Multirange.merge(\n    ...>   Warder.Multirange.new([Warder.Range.new!(1, 10), Warder.Range.new!(20, 30)])\n    ...> )\n    %Warder.Range{lower: 1, upper: 30, lower_inclusive: true, upper_inclusive: false}","ref":"Warder.Multirange.html#merge/1-examples"},{"type":"function","title":"Warder.Multirange.new/1","doc":"Create a new Multirange for the given ranges","ref":"Warder.Multirange.html#new/1"},{"type":"function","title":"Examples - Warder.Multirange.new/1","doc":"iex> Warder.Multirange.new([\n    ...>   Warder.Range.new!(1, 10),\n    ...>   Warder.Range.new!(5, 15),\n    ...>   Warder.Range.new!(20, 30)\n    ...>])\n    %Warder.Multirange{ranges: [\n      %Warder.Range{lower: 1, upper: 15, lower_inclusive: true, upper_inclusive: false},\n      %Warder.Range{lower: 20, upper: 30, lower_inclusive: true, upper_inclusive: false}\n    ]}","ref":"Warder.Multirange.html#new/1-examples"},{"type":"function","title":"Warder.Multirange.no_extend_left?/2","doc":"Does first not extend to the left of second?\n\nBoth `first` and `second` can either be a multirange or a range.","ref":"Warder.Multirange.html#no_extend_left?/2"},{"type":"function","title":"Examples - Warder.Multirange.no_extend_left?/2","doc":"iex> Warder.Multirange.no_extend_left?(\n    ...>   Warder.Multirange.new([Warder.Range.new!(20, 30)]),\n    ...>   Warder.Multirange.new([Warder.Range.new!(1, 10)])\n    ...> )\n    true\n\n    iex> Warder.Multirange.no_extend_left?(\n    ...>   Warder.Range.new!(20, 30),\n    ...>   Warder.Multirange.new([Warder.Range.new!(1, 10)])\n    ...> )\n    true\n\n    iex> Warder.Multirange.no_extend_left?(\n    ...>   Warder.Range.new!(1, 10),\n    ...>   Warder.Multirange.new([Warder.Range.new!(5, 10)])\n    ...> )\n    false","ref":"Warder.Multirange.html#no_extend_left?/2-examples"},{"type":"function","title":"Warder.Multirange.no_extend_right?/2","doc":"Does first not extend to the right of second?\n\nBoth `first` and `second` can either be a multirange or a range.","ref":"Warder.Multirange.html#no_extend_right?/2"},{"type":"function","title":"Examples - Warder.Multirange.no_extend_right?/2","doc":"iex> Warder.Multirange.no_extend_right?(\n    ...>   Warder.Multirange.new([Warder.Range.new!(1, 10)]),\n    ...>   Warder.Multirange.new([Warder.Range.new!(20, 30)])\n    ...> )\n    true\n\n    iex> Warder.Multirange.no_extend_right?(\n    ...>   Warder.Multirange.new([Warder.Range.new!(1, 10)]),\n    ...>   Warder.Range.new!(20, 30)\n    ...> )\n    true\n\n    iex> Warder.Multirange.no_extend_right?(\n    ...>   Warder.Multirange.new([Warder.Range.new!(1, 10)]),\n    ...>   Warder.Range.new!(1, 5)\n    ...> )\n    false","ref":"Warder.Multirange.html#no_extend_right?/2-examples"},{"type":"function","title":"Warder.Multirange.overlap?/2","doc":"Does `first` overlap with `second`, that is, do they have any common elements?\n\nBoth `first` and `second` can either be a multirange or a range.","ref":"Warder.Multirange.html#overlap?/2"},{"type":"function","title":"Examples - Warder.Multirange.overlap?/2","doc":"iex> Warder.Multirange.overlap?(\n    ...>   Warder.Multirange.new([Warder.Range.new!(1, 10)]),\n    ...>   Warder.Multirange.new([Warder.Range.new!(5, 15)])\n    ...> )\n    true\n\n    iex> Warder.Multirange.overlap?(\n    ...>   Warder.Multirange.new([Warder.Range.new!(1, 10)]),\n    ...>   Warder.Range.new!(5, 15)\n    ...> )\n    true\n\n    iex> Warder.Multirange.overlap?(\n    ...>   Warder.Multirange.new([Warder.Range.new!(1, 10)]),\n    ...>   Warder.Range.new!(20, 30)\n    ...> )\n    false","ref":"Warder.Multirange.html#overlap?/2-examples"},{"type":"function","title":"Warder.Multirange.right?/2","doc":"Is first strictly right of second?\n\nBoth `first` and `second` can either be a multirange or a range.","ref":"Warder.Multirange.html#right?/2"},{"type":"function","title":"Examples - Warder.Multirange.right?/2","doc":"iex> Warder.Multirange.right?(\n    ...>   Warder.Multirange.new([Warder.Range.new!(20, 30)]),\n    ...>   Warder.Multirange.new([Warder.Range.new!(1, 10)])\n    ...> )\n    true\n\n    iex> Warder.Multirange.right?(\n    ...>   Warder.Range.new!(20, 30),\n    ...>   Warder.Multirange.new([Warder.Range.new!(1, 10)])\n    ...> )\n    true\n\n    iex> Warder.Multirange.right?(\n    ...>   Warder.Range.new!(5, 15),\n    ...>   Warder.Multirange.new([Warder.Range.new!(1, 10)])\n    ...> )\n    false","ref":"Warder.Multirange.html#right?/2-examples"},{"type":"function","title":"Warder.Multirange.union/2","doc":"Computes the union of the multiranges.","ref":"Warder.Multirange.html#union/2"},{"type":"function","title":"Examples - Warder.Multirange.union/2","doc":"iex> Warder.Multirange.union(\n    ...>   Warder.Multirange.new([Warder.Range.new!(1, 10)]),\n    ...> Warder.Multirange.new([Warder.Range.new!(5, 15)])\n    ...> )\n    %Warder.Multirange{ranges: [\n      %Warder.Range{lower: 1, upper: 15, lower_inclusive: true, upper_inclusive: false}\n    ]}","ref":"Warder.Multirange.html#union/2-examples"},{"type":"type","title":"Warder.Multirange.t/0","doc":"","ref":"Warder.Multirange.html#t:t/0"},{"type":"type","title":"Warder.Multirange.t/1","doc":"","ref":"Warder.Multirange.html#t:t/1"},{"type":"module","title":"Warder.Query","doc":"`ecto` Query Helper Functions\n\nPostgres Functions and Operators:\nhttps://www.postgresql.org/docs/current/functions-range.html\n\nUsage: `require` or `import` `Warder.Query`","ref":"Warder.Query.html"},{"type":"module","title":"Postgres Types - Warder.Query","doc":"Make sure that you cast the types to the correct Postgres type. This can be\nachieved by using `Ecto.Query.API.type/2` or if the type is not directly\nsupported by ecto `fragment(\"?::type\", value)`.","ref":"Warder.Query.html#module-postgres-types"},{"type":"macro","title":"Warder.Query.adjacent?/2","doc":"Is `first` adjacent to `second`?\n\nOperator: `-|-`","ref":"Warder.Query.html#adjacent?/2"},{"type":"macro","title":"Signatures - Warder.Query.adjacent?/2","doc":"* `anyrange -|- anyrange → boolean`\n* `anymultirange -|- anymultirange → boolean`\n* `anymultirange -|- anyrange → boolean`\n* `anyrange -|- anymultirange → boolean`","ref":"Warder.Query.html#adjacent?/2-signatures"},{"type":"macro","title":"Examples - Warder.Query.adjacent?/2","doc":"where(\n      q in query,\n      where: adjacent?(q.range, type(Warder.Range.new!(1, 7), q.range))\n    )","ref":"Warder.Query.html#adjacent?/2-examples"},{"type":"macro","title":"Warder.Query.contained?/2","doc":"Is `first` contained in `second`?\n\nOperator: `<@`","ref":"Warder.Query.html#contained?/2"},{"type":"macro","title":"Signatures - Warder.Query.contained?/2","doc":"* `anyrange <@ anyrange → boolean`\n* `anyelement <@ anyrange → boolean`\n* `anymultirange <@ anymultirange → boolean`\n* `anymultirange <@ anyrange → boolean`\n* `anyrange <@ anymultirange → boolean`\n* `anyelement <@ anymultirange → boolean`","ref":"Warder.Query.html#contained?/2-signatures"},{"type":"macro","title":"Examples - Warder.Query.contained?/2","doc":"where(q in query, where: contained?(7, q.range))","ref":"Warder.Query.html#contained?/2-examples"},{"type":"macro","title":"Warder.Query.contains?/2","doc":"Does `first` contain `second`?\n\nOperator: `@>`","ref":"Warder.Query.html#contains?/2"},{"type":"macro","title":"Signatures - Warder.Query.contains?/2","doc":"* `anyrange @> anyrange → boolean`\n* `anyrange @> anyelement → boolean`\n* `anymultirange @> anymultirange → boolean`\n* `anymultirange @> anyrange → boolean`\n* `anymultirange @> anyelement → boolean`\n* `anyrange @> anymultirange → boolean`","ref":"Warder.Query.html#contains?/2-signatures"},{"type":"macro","title":"Examples - Warder.Query.contains?/2","doc":"where(q in query, where: contains?(q.range, 7))","ref":"Warder.Query.html#contains?/2-examples"},{"type":"macro","title":"Warder.Query.difference/2","doc":"Create difference of `first` and `second`.\n\nOperator: `-`","ref":"Warder.Query.html#difference/2"},{"type":"macro","title":"Signatures - Warder.Query.difference/2","doc":"* `anyrange - anyrange → anyrange`\n* `anymultirange - anymultirange → anymultirange`","ref":"Warder.Query.html#difference/2-signatures"},{"type":"macro","title":"Examples - Warder.Query.difference/2","doc":"where(\n      q in query,\n      select: type(difference(q.range, ^Range.new!(10, 20)), q.range))\n    )","ref":"Warder.Query.html#difference/2-examples"},{"type":"macro","title":"Warder.Query.empty?/1","doc":"Check if `subject` is empty.\n\nFunction: `ISEMPTY`","ref":"Warder.Query.html#empty?/1"},{"type":"macro","title":"Signatures - Warder.Query.empty?/1","doc":"* `isempty ( anyrange ) → boolean`\n* `isempty ( anymultirange ) → boolean`","ref":"Warder.Query.html#empty?/1-signatures"},{"type":"macro","title":"Examples - Warder.Query.empty?/1","doc":"where(\n      q in query,\n      select: is_empty?(q.range)\n    )","ref":"Warder.Query.html#empty?/1-examples"},{"type":"macro","title":"Warder.Query.intersection/2","doc":"Create intersection of `first` and `second`.\n\nOperator: `*`","ref":"Warder.Query.html#intersection/2"},{"type":"macro","title":"Signatures - Warder.Query.intersection/2","doc":"* `anyrange * anyrange → anyrange`\n* `anymultirange * anymultirange → anymultirange`","ref":"Warder.Query.html#intersection/2-signatures"},{"type":"macro","title":"Examples - Warder.Query.intersection/2","doc":"where(\n      q in query,\n      select: type(intersection(q.range, ^Range.new!(10, 20)), q.range))\n    )","ref":"Warder.Query.html#intersection/2-examples"},{"type":"macro","title":"Warder.Query.left?/2","doc":"Is `first` strictly left of `second`?\n\nOperator: `<<`","ref":"Warder.Query.html#left?/2"},{"type":"macro","title":"Signatures - Warder.Query.left?/2","doc":"* `anyrange << anyrange → boolean`\n* `anymultirange << anymultirange → boolean`\n* `anymultirange << anyrange → boolean`\n* `anyrange << anymultirange → boolean`","ref":"Warder.Query.html#left?/2-signatures"},{"type":"macro","title":"Examples - Warder.Query.left?/2","doc":"where(\n      q in query,\n      where: left?(q.range, type(Warder.Range.new!(1, 7), q.range))\n    )","ref":"Warder.Query.html#left?/2-examples"},{"type":"macro","title":"Warder.Query.lower/1","doc":"Get lower bound of range or multirange.\n\nFunction: `LOWER`","ref":"Warder.Query.html#lower/1"},{"type":"macro","title":"Signatures - Warder.Query.lower/1","doc":"* `lower ( anyrange ) → anyelement`\n* `lower ( anymultirange ) → anyelement`","ref":"Warder.Query.html#lower/1-signatures"},{"type":"macro","title":"Examples - Warder.Query.lower/1","doc":"where(\n      q in query,\n      select: lower(q.range)\n    )","ref":"Warder.Query.html#lower/1-examples"},{"type":"macro","title":"Warder.Query.lower_inclusive?/1","doc":"Check if lower of `subject` is inclusive.\n\nFunction: `LOWER_INC`","ref":"Warder.Query.html#lower_inclusive?/1"},{"type":"macro","title":"Signatures - Warder.Query.lower_inclusive?/1","doc":"* `lower_inc ( anyrange ) → boolean`\n* `lower_inc ( anymultirange ) → boolean`","ref":"Warder.Query.html#lower_inclusive?/1-signatures"},{"type":"macro","title":"Examples - Warder.Query.lower_inclusive?/1","doc":"where(\n      q in query,\n      select: is_lower_inclusive?(q.range)\n    )","ref":"Warder.Query.html#lower_inclusive?/1-examples"},{"type":"macro","title":"Warder.Query.lower_infinite?/1","doc":"Check if lower of `subject` is infinite.\n\nFunction: `LOWER_INF`","ref":"Warder.Query.html#lower_infinite?/1"},{"type":"macro","title":"Signatures - Warder.Query.lower_infinite?/1","doc":"* `lower_inf ( anyrange ) → boolean`\n* `lower_inf ( anymultirange ) → boolean`","ref":"Warder.Query.html#lower_infinite?/1-signatures"},{"type":"macro","title":"Examples - Warder.Query.lower_infinite?/1","doc":"where(\n      q in query,\n      select: is_lower_infinite?(q.range)\n    )","ref":"Warder.Query.html#lower_infinite?/1-examples"},{"type":"macro","title":"Warder.Query.merge_multirange/1","doc":"Merge multirange into range.\n\nFunction: `RANGE_MERGE`","ref":"Warder.Query.html#merge_multirange/1"},{"type":"macro","title":"Signatures - Warder.Query.merge_multirange/1","doc":"* `range_merge ( anymultirange ) → anyrange`","ref":"Warder.Query.html#merge_multirange/1-signatures"},{"type":"macro","title":"Examples - Warder.Query.merge_multirange/1","doc":"where(\n      q in query,\n      select: merge_multirange(q.multirange)\n    )","ref":"Warder.Query.html#merge_multirange/1-examples"},{"type":"macro","title":"Warder.Query.merge_ranges/2","doc":"Merge two ranges.\n\nFunction: `RANGE_MERGE`","ref":"Warder.Query.html#merge_ranges/2"},{"type":"macro","title":"Signatures - Warder.Query.merge_ranges/2","doc":"* `range_merge ( anyrange, anyrange ) → anyrange`","ref":"Warder.Query.html#merge_ranges/2-signatures"},{"type":"macro","title":"Examples - Warder.Query.merge_ranges/2","doc":"where(\n      q in query,\n      select: merge_ranges(q.range, q.range)\n    )","ref":"Warder.Query.html#merge_ranges/2-examples"},{"type":"macro","title":"Warder.Query.multirange/1","doc":"Create multirange from range.\n\nFunction: `MULTIRANGE`","ref":"Warder.Query.html#multirange/1"},{"type":"macro","title":"Signatures - Warder.Query.multirange/1","doc":"* `multirange ( anyrange ) → anymultirange`","ref":"Warder.Query.html#multirange/1-signatures"},{"type":"macro","title":"Examples - Warder.Query.multirange/1","doc":"where(\n      q in query,\n      select: multirange(q.range)\n    )","ref":"Warder.Query.html#multirange/1-examples"},{"type":"macro","title":"Warder.Query.no_extend_left?/2","doc":"Is `first` not extend to the left of `second`?\n\nOperator: `&>`","ref":"Warder.Query.html#no_extend_left?/2"},{"type":"macro","title":"Signatures - Warder.Query.no_extend_left?/2","doc":"* `anyrange &> anyrange → boolean`\n* `anymultirange &> anymultirange → boolean`\n* `anymultirange &> anyrange → boolean`\n* `anyrange &> anymultirange → boolean`","ref":"Warder.Query.html#no_extend_left?/2-signatures"},{"type":"macro","title":"Examples - Warder.Query.no_extend_left?/2","doc":"where(\n      q in query,\n      where: no_extend_left?(q.range, type(Warder.Range.new!(1, 7), q.range))\n    )","ref":"Warder.Query.html#no_extend_left?/2-examples"},{"type":"macro","title":"Warder.Query.no_extend_right?/2","doc":"Is `first` not extend to the right of `second`?\n\nOperator: `&<`","ref":"Warder.Query.html#no_extend_right?/2"},{"type":"macro","title":"Signatures - Warder.Query.no_extend_right?/2","doc":"* `anyrange &< anyrange → boolean`\n* `anymultirange &< anymultirange → boolean`\n* `anymultirange &< anyrange → boolean`\n* `anyrange &< anymultirange → boolean`","ref":"Warder.Query.html#no_extend_right?/2-signatures"},{"type":"macro","title":"Examples - Warder.Query.no_extend_right?/2","doc":"where(\n      q in query,\n      where: no_extend_right?(q.range, type(Warder.Range.new!(1, 7), q.range))\n    )","ref":"Warder.Query.html#no_extend_right?/2-examples"},{"type":"macro","title":"Warder.Query.overlap?/2","doc":"Does `first` overlap `second`?\n\nOperator: `&&`","ref":"Warder.Query.html#overlap?/2"},{"type":"macro","title":"Signatures - Warder.Query.overlap?/2","doc":"* `anyrange && anyrange → boolean`\n* `anymultirange && anymultirange → boolean`\n* `anymultirange && anyrange → boolean`\n* `anyrange && anymultirange → boolean`","ref":"Warder.Query.html#overlap?/2-signatures"},{"type":"macro","title":"Examples - Warder.Query.overlap?/2","doc":"where(\n      q in query,\n      where: overlap?(q.range, type(Warder.Range.new!(1, 7), q.range))\n    )","ref":"Warder.Query.html#overlap?/2-examples"},{"type":"macro","title":"Warder.Query.right?/2","doc":"Is `first` strictly right of `second`?\n\nOperator: `>>`","ref":"Warder.Query.html#right?/2"},{"type":"macro","title":"Signatures - Warder.Query.right?/2","doc":"* `anyrange >> anyrange → boolean`\n* `anymultirange >> anymultirange → boolean`\n* `anymultirange >> anyrange → boolean`\n* `anyrange >> anymultirange → boolean`","ref":"Warder.Query.html#right?/2-signatures"},{"type":"macro","title":"Examples - Warder.Query.right?/2","doc":"where(\n      q in query,\n      where: right?(q.range, type(Warder.Range.new!(1, 7), q.range))\n    )","ref":"Warder.Query.html#right?/2-examples"},{"type":"macro","title":"Warder.Query.union/2","doc":"Create union of `first` and `second`.\n\nOperator: `+`","ref":"Warder.Query.html#union/2"},{"type":"macro","title":"Signatures - Warder.Query.union/2","doc":"* `anyrange + anyrange → anyrange`\n* `anymultirange + anymultirange → anymultirange`","ref":"Warder.Query.html#union/2-signatures"},{"type":"macro","title":"Examples - Warder.Query.union/2","doc":"where(\n      q in query,\n      select: type(union(q.range, ^Range.new!(10, 20)), q.range))\n    )","ref":"Warder.Query.html#union/2-examples"},{"type":"macro","title":"Warder.Query.unnest/1","doc":"Unnest ranges from multirange.\n\nFunction: `UNNEST`","ref":"Warder.Query.html#unnest/1"},{"type":"macro","title":"Signatures - Warder.Query.unnest/1","doc":"* `unnest ( anymultirange ) → setof anyrange`","ref":"Warder.Query.html#unnest/1-signatures"},{"type":"macro","title":"Examples - Warder.Query.unnest/1","doc":"where(\n      q in query,\n      cross_join: r in unnest(q.multirange),\n      select: r\n    )","ref":"Warder.Query.html#unnest/1-examples"},{"type":"macro","title":"Warder.Query.upper/1","doc":"Get upper bound of `subject`.\n\nFunction: `UPPER`","ref":"Warder.Query.html#upper/1"},{"type":"macro","title":"Signatures - Warder.Query.upper/1","doc":"* `upper ( anyrange ) → anyelement`\n* `upper ( anymultirange ) → anyelement`","ref":"Warder.Query.html#upper/1-signatures"},{"type":"macro","title":"Examples - Warder.Query.upper/1","doc":"where(\n      q in query,\n      select: upper(q.range)\n    )","ref":"Warder.Query.html#upper/1-examples"},{"type":"macro","title":"Warder.Query.upper_inclusive?/1","doc":"Check if upper of `subject` is inclusive.\n\nFunction: `UPPER_INC`","ref":"Warder.Query.html#upper_inclusive?/1"},{"type":"macro","title":"Signatures - Warder.Query.upper_inclusive?/1","doc":"* `upper_inc ( anyrange ) → boolean`\n* `upper_inc ( anymultirange ) → boolean`","ref":"Warder.Query.html#upper_inclusive?/1-signatures"},{"type":"macro","title":"Examples - Warder.Query.upper_inclusive?/1","doc":"where(\n      q in query,\n      select: is_upper_inclusive?(q.range)\n    )","ref":"Warder.Query.html#upper_inclusive?/1-examples"},{"type":"macro","title":"Warder.Query.upper_infinite?/1","doc":"Check if upper of `subject` is infinite.\n\nFunction: `UPPER_INF`","ref":"Warder.Query.html#upper_infinite?/1"},{"type":"macro","title":"Signatures - Warder.Query.upper_infinite?/1","doc":"* `upper_inf ( anyrange ) → boolean`\n* `upper_inf ( anymultirange ) → boolean`","ref":"Warder.Query.html#upper_infinite?/1-signatures"},{"type":"macro","title":"Examples - Warder.Query.upper_infinite?/1","doc":"where(\n      q in query,\n      select: is_upper_infinite?(q.range)\n    )","ref":"Warder.Query.html#upper_infinite?/1-examples"},{"type":"module","title":"Warder.Range","doc":"Range Implementation\n\n> ##","ref":"Warder.Range.html"},{"type":"module","title":"Creation / Manipulation {: .warning} - Warder.Range","doc":">\n> Ranges should not be created or modified manually. Use `new/3`, `new!/3` or\n> `empty/0` to create ranges.","ref":"Warder.Range.html#module-creation-manipulation-warning"},{"type":"module","title":"Ecto Type - Warder.Range","doc":"If `ecto` and `postgrex` are installed, you can use the `Warder.Range` type:\n\n```elixir\ndefmodule Model do\n  use Ecto.Schema\n\n  alias Warder.Range\n\n  @type t :: %{range: Range.t(integer())}\n\n  schema \"models\" do\n    field :range, Range,\n      db_type: :int8range,\n      inner_type: :integer\n  end\nend\n```\n\n#","ref":"Warder.Range.html#module-ecto-type"},{"type":"module","title":"Options - Warder.Range","doc":"* `db_type` - The database type to use for the range column. For example\n  `:int8range`.\n* `inner_type` - The ecto type of the elements in the range. For example\n  `:integer`.","ref":"Warder.Range.html#module-options"},{"type":"function","title":"Warder.Range.adjacent?/2","doc":"Are the ranges adjacent?","ref":"Warder.Range.html#adjacent?/2"},{"type":"function","title":"Examples - Warder.Range.adjacent?/2","doc":"iex> Warder.Range.adjacent?(Warder.Range.new!(1, 10), Warder.Range.new!(10, 20))\n    true\n\n    iex> Warder.Range.adjacent?(Warder.Range.new!(1, 10), Warder.Range.new!(15, 20))\n    false","ref":"Warder.Range.html#adjacent?/2-examples"},{"type":"function","title":"Warder.Range.compare/2","doc":"Compare ranges for ordering\n\nThe module `Warder.Range` can be used as the `sorter` argument for\n`Enum.sort/2` and `Enum.sort_by/3`.","ref":"Warder.Range.html#compare/2"},{"type":"function","title":"Examples - Warder.Range.compare/2","doc":"iex> Warder.Range.compare(Warder.Range.new!(1, 10), Warder.Range.new!(5, 15))\n    :lt\n\n    iex> Warder.Range.compare(Warder.Range.new!(1, 10), Warder.Range.new!(1, 10))\n    :eq\n\n    iex> Warder.Range.compare(Warder.Range.new!(1, 10), Warder.Range.new!(0, 5))\n    :gt","ref":"Warder.Range.html#compare/2-examples"},{"type":"function","title":"Warder.Range.contains?/2","doc":"Does `first` contain `second`?\n\nBoth `first` and `second` can either be a range or an element.","ref":"Warder.Range.html#contains?/2"},{"type":"function","title":"Examples - Warder.Range.contains?/2","doc":"iex> Warder.Range.contains?(Warder.Range.new!(1, 10), Warder.Range.new!(5, 10))\n    true\n\n    iex> Warder.Range.contains?(Warder.Range.new!(1, 10), Warder.Range.new!(15, 20))\n    false\n\n    iex> Warder.Range.contains?(Warder.Range.new!(1, 10), 5)\n    true\n\n    iex> Warder.Range.contains?(Warder.Range.new!(1, 10), 20)\n    false","ref":"Warder.Range.html#contains?/2-examples"},{"type":"function","title":"Warder.Range.difference/2","doc":"Computes the difference of the ranges.\n\nThe second range must not be contained in the first in such a way that the\ndifference would not be a single range.","ref":"Warder.Range.html#difference/2"},{"type":"function","title":"Examples - Warder.Range.difference/2","doc":"iex> Warder.Range.difference(Warder.Range.new!(1, 10), Warder.Range.new!(5, 15))\n    {:ok, %Warder.Range{lower: 1, upper: 5, lower_inclusive: true, upper_inclusive: false}}\n\n    iex> Warder.Range.difference(Warder.Range.new!(1, 10), Warder.Range.new!(15, 20))\n    {:ok, %Warder.Range{lower: 1, upper: 10, lower_inclusive: true, upper_inclusive: false}}\n\n    iex> Warder.Range.difference(Warder.Range.new!(1, 10), Warder.Range.new!(2, 8))\n    {:error, %Warder.Range.DisjointRangesError{\n      lower: %Warder.Range{lower: 1, upper: 2, lower_inclusive: true, upper_inclusive: false},\n      upper: %Warder.Range{lower: 8, upper: 10, lower_inclusive: true, upper_inclusive: false}\n    }}","ref":"Warder.Range.html#difference/2-examples"},{"type":"function","title":"Warder.Range.difference!/2","doc":"Computes the difference of the ranges.\n\nSee `difference/2` for details.","ref":"Warder.Range.html#difference!/2"},{"type":"function","title":"Examples - Warder.Range.difference!/2","doc":"iex> Warder.Range.difference!(Warder.Range.new!(1, 10), Warder.Range.new!(5, 15))\n    %Warder.Range{lower: 1, upper: 5, lower_inclusive: true, upper_inclusive: false}\n\n    iex> Warder.Range.difference!(Warder.Range.new!(1, 10), Warder.Range.new!(2, 8))\n    ** (Warder.Range.DisjointRangesError) The result of range difference would not be contiguous.\n    Before difference: %Warder.Range{lower: 1, upper: 2, lower_inclusive: true, upper_inclusive: false}\n    After difference: %Warder.Range{lower: 8, upper: 10, lower_inclusive: true, upper_inclusive: false}","ref":"Warder.Range.html#difference!/2-examples"},{"type":"function","title":"Warder.Range.empty/0","doc":"Create a new empty range.","ref":"Warder.Range.html#empty/0"},{"type":"function","title":"Examples - Warder.Range.empty/0","doc":"iex> Warder.Range.empty()\n    %Warder.Range{lower: :empty, lower_inclusive: nil, upper: :empty, upper_inclusive: nil}","ref":"Warder.Range.html#empty/0-examples"},{"type":"function","title":"Warder.Range.intersection/2","doc":"Computes the intersection of the ranges.","ref":"Warder.Range.html#intersection/2"},{"type":"function","title":"Examples - Warder.Range.intersection/2","doc":"iex> Warder.Range.intersection(Warder.Range.new!(1, 10), Warder.Range.new!(5, 15))\n    %Warder.Range{lower: 5, upper: 10, lower_inclusive: true, upper_inclusive: false}\n\n    iex> Warder.Range.intersection(Warder.Range.new!(1, 10), Warder.Range.new!(15, 20))\n    %Warder.Range{lower: :empty, upper: :empty, lower_inclusive: nil, upper_inclusive: nil}","ref":"Warder.Range.html#intersection/2-examples"},{"type":"macro","title":"Warder.Range.is_empty/1","doc":"Guard to detect empty ranges.","ref":"Warder.Range.html#is_empty/1"},{"type":"function","title":"Warder.Range.left?/2","doc":"Is the first range strictly left of the second?","ref":"Warder.Range.html#left?/2"},{"type":"function","title":"Examples - Warder.Range.left?/2","doc":"iex> Warder.Range.left?(Warder.Range.new!(1, 10), Warder.Range.new!(11, 20))\n    true\n\n    iex> Warder.Range.left?(Warder.Range.new!(1, 10), Warder.Range.new!(5, 15))\n    false","ref":"Warder.Range.html#left?/2-examples"},{"type":"function","title":"Warder.Range.merge/2","doc":"Computes the smallest range that includes both of the given ranges.","ref":"Warder.Range.html#merge/2"},{"type":"function","title":"Examples - Warder.Range.merge/2","doc":"iex> Warder.Range.merge(Warder.Range.new!(1, 10), Warder.Range.new!(5, 15))\n    %Warder.Range{lower: 1, upper: 15, lower_inclusive: true, upper_inclusive: false}\n\n    iex> Warder.Range.merge(Warder.Range.new!(1, 10), Warder.Range.new!(15, 20))\n    %Warder.Range{lower: 1, upper: 20, lower_inclusive: true, upper_inclusive: false}","ref":"Warder.Range.html#merge/2-examples"},{"type":"function","title":"Warder.Range.new/3","doc":"Create a new range for the given bounds.\n\nThe lower bound must be less than or equal to the upper bound.\n\nIf the bounds are equal, that is, there are no values between the lower and\nupper bound, the resulting range is empty.\n\n> ##","ref":"Warder.Range.html#new/3"},{"type":"function","title":"Canonicalization {: .warning} - Warder.Range.new/3","doc":">\n> Ranges are canonicalized on creation. Therefore the bounds & inclusion might\n> shift to ensure the range is in a consistent state while keeping the same\n> meaning.","ref":"Warder.Range.html#new/3-canonicalization-warning"},{"type":"function","title":"Options - Warder.Range.new/3","doc":"* `:lower_inclusive` - Whether the lower bound is inclusive. Defaults to `true`.\n* `:upper_inclusive` - Whether the upper bound is inclusive. Defaults to `false`.","ref":"Warder.Range.html#new/3-options"},{"type":"function","title":"Examples - Warder.Range.new/3","doc":"iex> Warder.Range.new(1, 10)\n    {:ok, %Warder.Range{lower: 1, upper: 10, lower_inclusive: true, upper_inclusive: false}}\n\n    iex> Warder.Range.new(:unbound, 10)\n    {:ok, %Warder.Range{lower: :unbound, upper: 10, lower_inclusive: true, upper_inclusive: false}}\n\n    iex> Warder.Range.new(1, 1, upper_inclusive: false)\n    {:ok, %Warder.Range{lower: :empty, upper: :empty, lower_inclusive: nil, upper_inclusive: nil}}\n\n    iex> Warder.Range.new(10, 1)\n    {:error, %Warder.Range.BoundOrderError{lower: 10, upper: 1}}","ref":"Warder.Range.html#new/3-examples"},{"type":"function","title":"Warder.Range.new!/3","doc":"Create a new range for the given bounds.\n\nSee `new/3` for details.","ref":"Warder.Range.html#new!/3"},{"type":"function","title":"Examples - Warder.Range.new!/3","doc":"iex> Warder.Range.new!(1, 10)\n    %Warder.Range{lower: 1, upper: 10, lower_inclusive: true, upper_inclusive: false}\n\n    iex> Warder.Range.new!(10, 1)\n    ** (Warder.Range.BoundOrderError) The range lower bound (10) must be less than or equal to range upper bound (1).","ref":"Warder.Range.html#new!/3-examples"},{"type":"function","title":"Warder.Range.no_extend_left?/2","doc":"Does the first range not extend to the left of the second?","ref":"Warder.Range.html#no_extend_left?/2"},{"type":"function","title":"Examples - Warder.Range.no_extend_left?/2","doc":"iex> Warder.Range.no_extend_left?(Warder.Range.new!(5, 15), Warder.Range.new!(1, 10))\n    true\n\n    iex> Warder.Range.no_extend_left?(Warder.Range.new!(1, 10), Warder.Range.new!(5, 10))\n    false","ref":"Warder.Range.html#no_extend_left?/2-examples"},{"type":"function","title":"Warder.Range.no_extend_right?/2","doc":"Does the first range not extend to the right of the second?","ref":"Warder.Range.html#no_extend_right?/2"},{"type":"function","title":"Examples - Warder.Range.no_extend_right?/2","doc":"iex> Warder.Range.no_extend_right?(Warder.Range.new!(1, 10), Warder.Range.new!(5, 15))\n    true\n\n    iex> Warder.Range.no_extend_right?(Warder.Range.new!(1, 15), Warder.Range.new!(5, 10))\n    false","ref":"Warder.Range.html#no_extend_right?/2-examples"},{"type":"function","title":"Warder.Range.overlap?/2","doc":"Does the first range overlap with the second range, that is, have any elements\nin common?","ref":"Warder.Range.html#overlap?/2"},{"type":"function","title":"Examples - Warder.Range.overlap?/2","doc":"iex> Warder.Range.overlap?(Warder.Range.new!(1, 10), Warder.Range.new!(5, 15))\n    true\n\n    iex> Warder.Range.overlap?(Warder.Range.new!(1, 10), Warder.Range.new!(15, 20))\n    false","ref":"Warder.Range.html#overlap?/2-examples"},{"type":"function","title":"Warder.Range.right?/2","doc":"Is the first range strictly right of the second?","ref":"Warder.Range.html#right?/2"},{"type":"function","title":"Examples - Warder.Range.right?/2","doc":"iex> Warder.Range.right?(Warder.Range.new!(11, 20), Warder.Range.new!(1, 10))\n    true\n\n    iex> Warder.Range.right?(Warder.Range.new!(5, 15), Warder.Range.new!(1, 10))\n    false","ref":"Warder.Range.html#right?/2-examples"},{"type":"function","title":"Warder.Range.union/2","doc":"Computes the union of the ranges.\n\nThe ranges must overlap or be adjacent, so that the union is a single range.","ref":"Warder.Range.html#union/2"},{"type":"function","title":"Examples - Warder.Range.union/2","doc":"iex> Warder.Range.union(Warder.Range.new!(1, 10), Warder.Range.new!(5, 15))\n    {:ok, %Warder.Range{lower: 1, upper: 15, lower_inclusive: true, upper_inclusive: false}}\n\n    iex> Warder.Range.union(Warder.Range.new!(1, 10), Warder.Range.new!(15, 20))\n    {:error, %Warder.Range.NotContiguousError{\n      first: %Warder.Range{lower: 1, upper: 10, lower_inclusive: true, upper_inclusive: false},\n      second: %Warder.Range{lower: 15, upper: 20, lower_inclusive: true, upper_inclusive: false}\n    }}","ref":"Warder.Range.html#union/2-examples"},{"type":"function","title":"Warder.Range.union!/2","doc":"Computes the union of the ranges.\n\nSee `union/2`.","ref":"Warder.Range.html#union!/2"},{"type":"function","title":"Examples - Warder.Range.union!/2","doc":"iex> Warder.Range.union!(Warder.Range.new!(1, 10), Warder.Range.new!(5, 15))\n    %Warder.Range{lower: 1, upper: 15, lower_inclusive: true, upper_inclusive: false}\n\n    iex> Warder.Range.union!(Warder.Range.new!(1, 10), Warder.Range.new!(15, 20))\n    ** (Warder.Range.NotContiguousError) The first range and second range are not contiguous.\n    First: %Warder.Range{lower: 1, upper: 10, lower_inclusive: true, upper_inclusive: false}\n    Second: %Warder.Range{lower: 15, upper: 20, lower_inclusive: true, upper_inclusive: false}","ref":"Warder.Range.html#union!/2-examples"},{"type":"type","title":"Warder.Range.empty/0","doc":"An empty range is one that does not contain any values between the lower and\nupper bounds.","ref":"Warder.Range.html#t:empty/0"},{"type":"type","title":"Warder.Range.specified/1","doc":"Range with specified bounds.","ref":"Warder.Range.html#t:specified/1"},{"type":"type","title":"Fields - Warder.Range.specified/1","doc":"* `lower` - The lower bound of the range.\n* `upper` - The upper bound of the range.\n* `lower_inclusive` - Whether the lower bound is inclusive.\n* `upper_inclusive` - Whether the upper bound is inclusive.","ref":"Warder.Range.html#t:specified/1-fields"},{"type":"type","title":"Warder.Range.t/0","doc":"A range of any `subtype`.","ref":"Warder.Range.html#t:t/0"},{"type":"type","title":"Warder.Range.t/1","doc":"A specified or empty range with the bound type of `subtype`.","ref":"Warder.Range.html#t:t/1"},{"type":"exception","title":"Warder.Range.BoundOrderError","doc":"Error when the range bounds are not in ascending order.","ref":"Warder.Range.BoundOrderError.html"},{"type":"type","title":"Warder.Range.BoundOrderError.t/0","doc":"","ref":"Warder.Range.BoundOrderError.html#t:t/0"},{"type":"type","title":"Warder.Range.BoundOrderError.t/1","doc":"","ref":"Warder.Range.BoundOrderError.html#t:t/1"},{"type":"exception","title":"Warder.Range.DisjointRangesError","doc":"Error when the result of range difference would not be contiguous.","ref":"Warder.Range.DisjointRangesError.html"},{"type":"type","title":"Warder.Range.DisjointRangesError.t/0","doc":"","ref":"Warder.Range.DisjointRangesError.html#t:t/0"},{"type":"type","title":"Warder.Range.DisjointRangesError.t/1","doc":"","ref":"Warder.Range.DisjointRangesError.html#t:t/1"},{"type":"exception","title":"Warder.Range.NotContiguousError","doc":"Error when the ranges are not contiguous.","ref":"Warder.Range.NotContiguousError.html"},{"type":"type","title":"Warder.Range.NotContiguousError.t/0","doc":"","ref":"Warder.Range.NotContiguousError.html#t:t/0"},{"type":"type","title":"Warder.Range.NotContiguousError.t/1","doc":"","ref":"Warder.Range.NotContiguousError.html#t:t/1"},{"type":"extras","title":"README","doc":"# Warder\n\nLibrary to manage ranges of arbitrary type.\n\n[![Main Branch](https://github.com/sustema-ag/warder/actions/workflows/branch_main.yml/badge.svg?branch=main)](https://github.com/sustema-ag/warder/actions/workflows/branch_main.yml)\n[![Module Version](https://img.shields.io/hexpm/v/warder.svg)](https://hex.pm/packages/warder)\n[![Total Download](https://img.shields.io/hexpm/dt/warder.svg)](https://hex.pm/packages/warder)\n[![License](https://img.shields.io/hexpm/l/warder.svg)](https://github.com/sustema-ag/warder/blob/main/LICENSE)\n[![Last Updated](https://img.shields.io/github/last-commit/sustema-ag/warder.svg)](https://github.com/sustema-ag/warder/commits/master)\n[![Coverage Status](https://coveralls.io/repos/github/sustema-ag/warder/badge.svg?branch=main)](https://coveralls.io/github/sustema-ag/warder?branch=main)","ref":"readme.html"},{"type":"extras","title":"Usage - README","doc":"```elixir\nRange.adjacent?(Range.new!(1, 100), Range.new!(100, 200))\n# => true\n\nRange.contains?(Range.new!(1, 100), Range.new!(20, 30))\n# => true\n\nRange.overlap?(Range.new!(1, 100), Range.new!(200, 300))\n# => false\n\n# And many more, check the docs :)\n```\n\n#","ref":"readme.html#usage"},{"type":"extras","title":"Ecto - README","doc":"`Warder.Range` and `Warder.Multirange` are [Parameterized `ecto` Types](https://hexdocs.pm/ecto/3.11.2/Ecto.ParameterizedType.html).","ref":"readme.html#ecto"},{"type":"extras","title":"Installation - README","doc":"The package can be installed by adding `warder` to your list of dependencies in\n`mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:warder, \"~> 0.1.0\"}\n  ]\nend\n```\n\nThe docs can be found at  .","ref":"readme.html#installation"}],"content_type":"text/markdown","producer":{"name":"ex_doc","version":[48,46,51,49,46,50]}}